@@ -4,9 +4,7 @@
  *
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @author Jared Watkins 2003 <jared@watkins.net>
- * @package amavisnewsql
- * $Id: amavisnewsql.class.php, v
-*/
+ */
 
 /**
  * Load our config files
@@ -54,7 +52,7 @@ class AmavisNewSQL {
       var $error;
 
 
-      function AmavisNewSQL($calledfrom=NULL, $line=NULL) {
+      function AmavisNewSQL() {
          global $CONFIG;
 
          $this->dsn = $CONFIG["dsn"];
@@ -77,14 +75,14 @@ class AmavisNewSQL {
       * @param array alist
       * @returns bool True on success Fale on failure
       */
-      function Whitelist_Addressbook($username, $alist, $calledfrom=NULL, $line=NULL) {
+      function Whitelist_Addressbook($username, $alist) {
           $this->error = null;
           if (!is_array($alist)) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
               return FALSE;
           }
 
-          if (!$wblist = $this->ReadWBList($username, $calledfrom, $line)) return FALSE;
+          if (!$wblist = $this->ReadWBList($username)) return FALSE;
           if ($wblist == -1) $wblist = 0; // Due to the stupid way empty arrays wont pass is_array
 
           $addressestoadd = array();
@@ -111,7 +109,7 @@ class AmavisNewSQL {
           }
 
           for ($i=0; $i < count($addressestoadd); $i++) {
-            if (!$this->AddEditWBList($username, "W", 7, $addressestoadd[$i], NULL, $calledfrom, $line)) {
+            if (!$this->AddEditWBList($username, "W", 7, $addressestoadd[$i])) {
                 return FALSE;
             }
           }
@@ -126,7 +124,7 @@ class AmavisNewSQL {
       * @param string username
       * @returns bool True on success Fale on failure
       */
-      function WListMessages($msg, $username, $calledfrom=NULL, $line=NULL) {
+      function WListMessages($msg, $username) {
           $this->error = null;
           if (!is_array($msg) || !is_string($username)) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -141,12 +139,12 @@ class AmavisNewSQL {
                     and $this->msgowner_table.msgid = $msg[$i]
                     ";
 
-              if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+              if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
               $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
               $sender_email = $row["sender"];
 
-              if (!$this->AddEditWBList($username, "W", 7, $sender_email, NULL, $calledfrom, $line)) {
+              if (!$this->AddEditWBList($username, "W", 7, $sender_email)) {
                  return FALSE;
               }
           }
@@ -162,7 +160,7 @@ class AmavisNewSQL {
       * @param string username
       * @returns bool True on success Fale on failure
       */
-      function ReleaseQuarantineMessages($msg, $username, $calledfrom=NULL, $line=NULL) {
+      function ReleaseQuarantineMessages($msg, $username) {
           $this->error = null;
           if (!is_array($msg) || !is_string($username)) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -173,7 +171,7 @@ class AmavisNewSQL {
 
           $q = "select email from $this->users_table where username = '$username'";
 
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
           $email_address = $row["email"];
@@ -199,7 +197,7 @@ class AmavisNewSQL {
                  and $this->users_table.username = '$username'
                  ";
 
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           $smtp = new Net_SMTP($this->smtp_host, $this->smtp_port);
 
@@ -226,7 +224,7 @@ class AmavisNewSQL {
               }
 
               $smtp->disconnect();
-              $this->DeleteQuarantineMessages($row["messageid"], $username, $calledfrom, $line);
+              $this->DeleteQuarantineMessages($row["messageid"], $username);
 
           }
           return TRUE;
@@ -241,7 +239,7 @@ class AmavisNewSQL {
       * @param string username
       * @returns bool True on success False on failure Null on not found
       */
-      function RemoveUser($username, $calledfrom=NULL, $line=NULL) {
+      function RemoveUser($username) {
           $this->error = null;
           if ($username == null || !is_string($username)) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -261,14 +259,14 @@ class AmavisNewSQL {
                 and $this->users_table.username = '$username'
                 ";
 
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           // Delete each message
           $numrows = $res->numRows();
           if ($numrows > 0) {
               for ($i=0; $i < $numrows; $i++) {
                    $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
-                   $this->DeleteQuarantineMessage($row["msgid"], $username, $calledfrom, $line);
+                   $this->DeleteQuarantineMessage($row["msgid"], $username);
               }
           }
 
@@ -279,7 +277,7 @@ class AmavisNewSQL {
 
           $q = "select policy_id from $this->users_table where id = $uid";
 
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
           $policyid = $row["policy_id"];
@@ -287,18 +285,18 @@ class AmavisNewSQL {
           if ($policyid > 10) {  // 10 and below are system policies.. don't delete those =]
 
               $q = "delete from $this->policy_table where id = $policyid";
-              if (!$res = $this->sqlWrite($q, $calledfrom, $line)) return FALSE;
+              if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) return FALSE;
 
           }
 
           // Remove all W/B list entries
 
           $q = "delete from $this->wblist_table where rid = $uid";
-          if (!$res = $this->sqlWrite($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) return FALSE;
 
           // Finally... remove the entry from the users table
           $q = "delete from $this->users_table where id = $uid";
-          if (!$res = $this->sqlWrite($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) return FALSE;
 
           return TRUE;
       }
@@ -311,7 +309,7 @@ class AmavisNewSQL {
       * @param string Username
       * @returns True on success False on failure
       */
-      function DeleteQuarantineMessages($msg, $username, $calledfrom=NULL, $line=NULL) {
+      function DeleteQuarantineMessages($msg, $username) {
           $this->error = null;
           if ($username == null || $msg == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -322,25 +320,25 @@ class AmavisNewSQL {
                                 // from within the webmail app
 
               for ($i=0; $i < count($msg); $i++) {
-                  $owners = $this->_HowManyOwners($msg[$i], $calledfrom, $line);
+                  $owners = $this->_HowManyOwners($msg[$i]);
 
                   if ($owners > 1) {
                       // More than one person has this in their quarantine so don't touch the msg table
 
-                      $this->_RemoveMessage($msg[$i], $username, "partial", $calledfrom, $line);
+                      $this->_RemoveMessage($msg[$i], $username, "partial");
 
                   } else {
 
-                      $this->_RemoveMessage($msg[$i], $username, "complete", $calledfrom, $line);
+                      $this->_RemoveMessage($msg[$i], $username, "complete");
                   }
               }
 
           } else if (is_numeric($msg)) {  // This one is mostly used from other methods of the class
 
-              $owners = $this->_HowManyOwners($msg, $calledfrom, $line);
+              $owners = $this->_HowManyOwners($msg);
 
-              if($owners > 1) $this->_RemoveMessage($msg, $username, "partial", $calledfrom, $line);
-              else            $this->_RemoveMessage($msg, $username, "complete", $calledfrom, $line);
+              if($owners > 1) $this->_RemoveMessage($msg, $username, "partial");
+              else            $this->_RemoveMessage($msg, $username, "complete");
 
               return null;  // If $msg was an int stop here
 
@@ -362,26 +360,26 @@ class AmavisNewSQL {
       * @param string method
       * @returns True on success False on failure
       */
-      function _RemoveMessage($msgid, $username, $method, $calledfrom=NULL, $line=NULL) {
+      function _RemoveMessage($msgid, $username, $method) {
           $this->error = null;
           if ($username == null || $msgid == null || $method == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
               return FALSE;
           }
 
-          if(!$uid = $this->uid($username, $calledfrom, $line)) {
+          if(!$uid = $this->uid($username)) {
                return FALSE;
           }
 
-          $this->sqlWrite("begin", $calledfrom, $line);
+          $this->sqlWrite("begin");
 
           $q = "delete from $this->msgowner_table
                 where $this->msgowner_table.msgid = $msgid
                 and rid = $uid";
 
-          if (!$res = $this->sqlWrite($q, $calledfrom, $line)) {
-               $this->sqlWrite("rollback", $calledfrom, $line);
-               $this->disconnect($calledfrom, $line);
+          if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+               $this->sqlWrite("rollback");
+               $this->disconnect();
                return FALSE;
           }
 
@@ -390,15 +388,15 @@ class AmavisNewSQL {
               $q = "delete from $this->msg_table
                     where $this->msg_table.id = $msgid";
 
-              if (!$res = $this->sqlWrite($q, $calledfrom, $line)) {
-                   $this->sqlWrite("rollback", $calledfrom, $line);
-                   $this->disconnect($calledfrom, $line);
+              if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                   $this->sqlWrite("rollback");
+                   $this->disconnect();
                    return FALSE;
               }
 
           }
 
-          $this->sqlWrite("commit", $calledfrom, $line);
+          $this->sqlWrite("commit");
       }
 
 
@@ -410,7 +408,7 @@ class AmavisNewSQL {
       * @param string messageid
       * @returns mixed Number on success False on Failure
       */
-      function _HowManyOwners($msgid, $calledfrom=NULL, $line=NULL) {
+      function _HowManyOwners($msgid) {
           $this->error = null;
           if ($msgid == null || !is_numeric($msgid)) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -418,7 +416,7 @@ class AmavisNewSQL {
           }
 
           $q = "select rid from $this->msgowner_table where $this->msgowner_table.msgid = $msgid";
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           return $res->numRows();
       }
@@ -432,7 +430,7 @@ class AmavisNewSQL {
       * @param string username
       * @returns bool True on exists False on duplicate and Null on not found
       */
-      function UserExists($username, $calledfrom=NULL, $line=NULL) {
+      function UserExists($username) {
           $this->error = null;
           if ($username == null || !is_string($username)) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -443,7 +441,7 @@ class AmavisNewSQL {
                 from $this->users_table
                 where username = '$username'";
 
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           $num = $res->numRows();
           if($num == 1) {
@@ -467,7 +465,7 @@ class AmavisNewSQL {
       * @param string data_dir from squirrelmail
       * @returns bool True on success False on failure
       */
-      function CreateUser($username, $data_dir, $calledfrom=NULL, $line=NULL) {
+      function CreateUser($username, $data_dir) {
           $this->error = null;
           if ($username == null || $data_dir == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -487,7 +485,7 @@ class AmavisNewSQL {
                     (id, username, email, fullname)
                      values ('$nextid', '$username', '$email', '$full_name')";
 
-              if (!$res = $this->sqlWrite($q, $calledfrom, $line)) return FALSE;
+              if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) return FALSE;
 
               return TRUE;
       }
@@ -503,7 +501,7 @@ class AmavisNewSQL {
       * @param string address
       * @returns bool True on success False on failure
       */
-      function AddressSanityCheck($address, $calledfrom=NULL, $line=NULL)
+      function AddressSanityCheck($address)
       {
           $this->error = null;
           if ($address == null) {
@@ -531,7 +529,7 @@ class AmavisNewSQL {
       * @param int Row Defaults to null for add operations otherwise indicates the row number for that users list
       * @returns bool True on success False on failure
       */
-      function AddEditWBList($username, $wb, $priority, $address, $row = null, $calledfrom=NULL, $line=NULL) {
+      function AddEditWBList($username, $wb, $priority, $address, $row = null) {
           $this->error = null;
           if ($username == null || $wb == null || $priority == null || $address == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -550,36 +548,36 @@ class AmavisNewSQL {
 
                 $q = "select * from $this->wblist_table where email = '$address' and $this->wblist_table.rid = '$uid'";
 
-                if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+                if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
                 if($res->numRows() > 0) {
                    $this->error = "You Already Have That Address in Your List";
                    return FALSE;
                 }
 
-                $this->sqlWrite("begin", $calledfrom, $line);
+                $this->sqlWrite("begin");
 
                 $q = "insert into $this->wblist_table
                       (rid, priority, email, wb)
                       values ('$uid', '$priority', '$address', '$wb')";
 
-                 if (!$res = $this->sqlWrite($q, $calledfrom, $line)) {
-                      $this->sqlWrite("rollback", $calledfrom, $line);
-                      $this->disconnect($calledfrom, $line);
+                 if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                      $this->sqlWrite("rollback");
+                      $this->disconnect();
                       return FALSE;
                  }
 
-                $this->sqlWrite("commit", $calledfrom, $line);
+                $this->sqlWrite("commit");
 
           } else if(is_numeric($row)) {  // This is a change operation
 
-               if (!$wbList = $this->ReadWBList($username, $calledfrom, $line)) return FALSE;
+               if (!$wbList = $this->ReadWBList($username)) return FALSE;
                if ($wbList == -1) $wbList = 0;
 
                for($i=0; $i <= count($wbList); $i++) {
                    if($i == $row) { // Make sure we are working on the right row from that users personal list
 
-                      $this->sqlWrite("begin", $calledfrom, $line);
+                      $this->sqlWrite("begin");
 
                       $q = "update $this->wblist_table
                             set priority = '$priority',
@@ -588,16 +586,16 @@ class AmavisNewSQL {
                             where rid = '".$wbList[$i]["rid"]."'
                             and email = '".$wbList[$i]["email"]."'";
 
-                      if (!$res = $this->sqlWrite($q, $calledfrom, $line)) {
-                           $this->sqlWrite("rollback", $calledfrom, $line);
-                           $this->disconnect($calledfrom, $line);
+                      if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                           $this->sqlWrite("rollback");
+                           $this->disconnect();
                            return FALSE;
                       }
 
-                      $this->sqlWrite("commit", $calledfrom, $line);
+                      $this->sqlWrite("commit");
                    }
                } //for
-               $this->sqlWrite("commit", $calledfrom, $line);
+               $this->sqlWrite("commit");
           }  // if add or update
           return TRUE;
       }
@@ -611,7 +609,7 @@ class AmavisNewSQL {
       * @param float Kill / Quarantine Level
       * @returns bool True on success False on failure
       */
-      function SetCustomPolicy($username, $tag2_level, $kill_level, $calledfrom=NULL, $line=NULL) {
+      function SetCustomPolicy($username, $tag2_level, $kill_level) {
           $this->error = null;
           if($username == null || $tag2_level == null || $kill_level == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -622,12 +620,12 @@ class AmavisNewSQL {
 
           $q = "select id,policy_id from $this->users_table where username = '$username'";
 
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
           $uid = $row["id"];
 
-          $this->sqlWrite("begin", $calledfrom, $line);
+          $this->sqlWrite("begin");
 
           if($row["policy_id"] > 10) {        // We are changing an existing custom policy
              $q = "update $this->policy_table
@@ -635,9 +633,9 @@ class AmavisNewSQL {
                        spam_kill_level = '$kill_level'
                    where id = $row[policy_id]";
 
-             if (!$res = $this->sqlWrite($q, $calledfrom, $line)) {
-                 $this->sqlWrite("rollback", $calledfrom, $line);
-                 $this->disconnect($calledfrom, $line);
+             if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                 $this->sqlWrite("rollback");
+                 $this->disconnect();
                  return FALSE;
              }
 
@@ -648,19 +646,22 @@ class AmavisNewSQL {
                   (id,policy_name,spam_tag2_level,spam_kill_level)
                    values ($nextid,'Custom','$tag2_level','$kill_level')";
 
-             $res1 = $this->sqlWrite($q, $calledfrom, $line);
+             if (!$res1 = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                 $this->sqlWrite("rollback");
+                 $this->disconnect();
+                 return FALSE;
+             }
 
              $q = "update $this->users_table set policy_id = '$nextid' where id = '$uid'";
-             $res = $this->sqlWrite($q, $calledfrom, $line);
 
-             if ($res == FALSE || $res1 == FALSE) {
-                 $this->sqlWrite("rollback", $calledfrom, $line);
-                 $this->disconnect($calledfrom, $line);
+             if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                 $this->sqlWrite("rollback");
+                 $this->disconnect();
                  return FALSE;
              }
           }
 
-          $this->sqlWrite("commit", $calledfrom, $line);
+          $this->sqlWrite("commit");
           return TRUE;
       }
 
@@ -672,7 +673,7 @@ class AmavisNewSQL {
       * @param int Policy ID to set on user
       * @returns bool True on success False on failure
       */
-      function SetPolicy($username, $target_id, $calledfrom=NULL, $line=NULL) {
+      function SetPolicy($username, $target_id) {
           $this->error = null;
           if($username == null || $target_id == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -680,19 +681,19 @@ class AmavisNewSQL {
           }
 
           $q = "select id,policy_id from $this->users_table where username = '$username'";
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
           $uid = $row["id"];
 
-          $this->sqlWrite("begin", $calledfrom, $line);
+          $this->sqlWrite("begin");
 
           if($row["policy_id"] < 10) {
              $q = "update $this->users_table
                    set policy_id = '$target_id'
                    where id = '$uid'";
 
-             if (!$res = $this->sqlWrite($q, $calledfrom, $line)) return FALSE;
+             if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) return FALSE;
 
           } else {
              // Since we are dumping a custom Policy Remove the entry from the policy table
@@ -700,20 +701,20 @@ class AmavisNewSQL {
             $del = "delete from $this->policy_table where id = '$row[policy_id]'";
             $q   = "update $this->users_table set policy_id = '$target_id' where id = '$uid'";
 
-            if (!$res = $this->sqlWrite($q, $calledfrom, $line)) {
-                $this->sqlWrite("rollback", $calledfrom, $line);
-                $this->disconnect($calledfrom, $line);
+            if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                $this->sqlWrite("rollback");
+                $this->disconnect();
                 return FALSE;
             }
 
-            if (!$res = $this->sqlWrite($del, $calledfrom, $line)) {
-                $this->sqlWrite("rollback", $calledfrom, $line);
-                $this->disconnect($calledfrom, $line);
+            if (!$res = $this->sqlWrite($del, __FUNCTION__, __LINE__)) {
+                $this->sqlWrite("rollback");
+                $this->disconnect();
                 return FALSE;
             }
 
           }
-          $this->sqlWrite("commit", $calledfrom, $line);
+          $this->sqlWrite("commit");
           return TRUE;
       }
 
@@ -749,7 +750,7 @@ class AmavisNewSQL {
       * @param int Days to retain messages in quarantine
       * @returns bool True on success False on failure
       */
-      function SetQuarantineSettings($username, $freq, $retention, $calledfrom=NULL, $line=NULL) {
+      function SetQuarantineSettings($username, $freq, $retention) {
           $this->error = null;
           if($username == null || ($freq == null && $retention == null)) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -767,7 +768,7 @@ class AmavisNewSQL {
 
                  $q = "update $this->users_table set digest = '$freq' where username = '$username'";
 
-                 if (!$res = $this->sqlWrite($q, $calledfrom, $line)) return FALSE;
+                 if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) return FALSE;
              }
           }
 
@@ -779,7 +780,7 @@ class AmavisNewSQL {
 
                 $q = "update $this->users_table set retention = '$retention' where username = '$username'";
 
-                if (!$res = $this->sqlWrite($q, $calledfrom, $line)) return FALSE;
+                if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) return FALSE;
 
              }
           }
@@ -793,7 +794,7 @@ class AmavisNewSQL {
       * @param string username
       * @returns mixed Array on success and False on failure
       */
-      function ReadQuarantineSettings($username, $calledfrom=NULL, $line=NULL) {
+      function ReadQuarantineSettings($username) {
           $this->error = null;
           if($username == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -802,7 +803,7 @@ class AmavisNewSQL {
 
           $q = "select digest, retention from $this->users_table where username = '$username'";
 
-          if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+          if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
           $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
 
@@ -837,17 +838,17 @@ class AmavisNewSQL {
       * @param int Matching row of WBList to delete
       * @returns bool True on success False on failure
       */
-      function DeleteWBAddress($username, $delrow, $calledfrom=NULL, $line=NULL) {
+      function DeleteWBAddress($username, $delrow) {
           $this->error = null;
           if($username == null || $delrow == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
               return FALSE;
           }
 
-          if (!$wbList = $this->ReadWBList($username, $calledfrom, $line)) return FALSE;
+          if (!$wbList = $this->ReadWBList($username)) return FALSE;
           if ($wbList == -1) $wbList = array();
 
-          $this->sqlWrite("begin", $calledfrom, $line);
+          $this->sqlWrite("begin");
 
           if (count($wbList) == 0) return TRUE;
 
@@ -857,14 +858,14 @@ class AmavisNewSQL {
                        where rid = '".$wbList[$i]["rid"]."'
                        and email = '".$wbList[$i]["address"]."'";
 
-                 if (!$res = $this->sqlWrite($q, $calledfrom, $line)) {
-                     $this->sqlWrite("rollback", $calledfrom, $line);
-                     $this->disconnect($calledfrom, $line);
+                 if (!$res = $this->sqlWrite($q, __FUNCTION__, __LINE__)) {
+                     $this->sqlWrite("rollback");
+                     $this->disconnect();
                      return FALSE;
                  }
               }
           }
-          $this->sqlWrite("commit", $calledfrom, $line);
+          $this->sqlWrite("commit");
           return TRUE;
       }
 
@@ -875,7 +876,7 @@ class AmavisNewSQL {
       * @param string username
       * @returns mixed Array of data on success or False on failure
       */
-      function ReadPolicyList($username = '%', $calledfrom=NULL, $line=NULL) {
+      function ReadPolicyList($username = '%') {
          $this->error = null;
           if($username == "%") {
             $q = "select *
@@ -889,12 +890,12 @@ class AmavisNewSQL {
                      $this->users_table.id,
                      $this->users_table.email
                   from $this->policy_table, $this->users_table
-                  where $this->users_table.policy_id = policy.id
+                  where $this->users_table.policy_id = $this->policy_table.id
                   and $this->users_table.username = '$username'
                   order by $this->policy_table.id";
          }
 
-         if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+         if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
          $PolicyList = array();
 
@@ -916,7 +917,7 @@ class AmavisNewSQL {
       * @param string username
       * @returns mixed Array of data on success or False on failure -1 on 0 List entries found
       */
-      function ReadWBList($username, $calledfrom=NULL, $line=NULL) {
+      function ReadWBList($username) {
           $this->error = null;
           if($username == null) {
               $this->error = "Improper arguments supplied for ".__FUNCTION__." function";
@@ -932,7 +933,7 @@ class AmavisNewSQL {
               order by $this->wblist_table.priority desc, $this->wblist_table.email";
 
 
-         if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+         if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
          $wblist = array();
          for($i=0; $i < $res->numRows(); $i++) {
@@ -955,7 +956,7 @@ class AmavisNewSQL {
       * @param object Result set object
       * @returns string Error Message
       */
-      function dbErrorMessage($res, $calledfrom=NULL, $line=NULL) {
+      function dbErrorMessage($res) {
           while (list($key, $value) = each ($res)) {
               if($key == "message" || $key == "userinfo") {
                   $message .= " = ".$value;
@@ -970,7 +971,7 @@ class AmavisNewSQL {
       * @param string username or email address
       * @returns int on success False on failure
       */
-      function uid($string, $calledfrom=NULL, $line=NULL) {
+      function uid($string) {
          $this->error = null;
 
          if(ereg("@", $string)) {
@@ -980,7 +981,7 @@ class AmavisNewSQL {
          }
 
 
-         if (!$res = $this->sqlRead($q, $calledfrom, $line)) return FALSE;
+         if (!$res = $this->sqlRead($q, __FUNCTION__, __LINE__)) return FALSE;
 
          $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
 
@@ -995,17 +996,17 @@ class AmavisNewSQL {
       * @param int Line number of calling function again for error messages (Optional)
       * @returns mixed Result Set on success or False on failure
       */
-      function sqlWrite($query, $calledfrom=NULL, $line=NULL) {
+      function sqlWrite($query, $calledfrom=null, $line=null) {
          $this->error = null;
 
          if (!is_string($query)) {
-              $this->error = "Improper arguments supplied for ".__FUNCTION__." method called from $calledfrom on line $line";
+              $this->error = "Improper arguments supplied for ".__FUNCTION__." method from $calledfrom on line $line";
               return FALSE;
           }
 
          $res = $this->db->query($query);
          if(DB::isError($res)) {
-            $this->error = "DB Error = '".$this->dbErrorMessage($res)."' called from $calledfrom on line $line";            return FALSE;
+            $this->error = "DB Error in ".__FUNCTION__." Message = '".$this->dbErrorMessage($res)."' called from $calledfrom on line $line";            return FALSE;
          }
 
          return $res;
@@ -1018,7 +1019,7 @@ class AmavisNewSQL {
       * @param int Line number of calling function again for error messages (Optional)
       * @returns mixed Result Set on success or False on failure
       */
-      function sqlRead($query, $calledfrom=NULL, $line=NULL) {
+      function sqlRead($query, $calledfrom=null, $line=null) {
          $this->error = null;
 
          if (!is_string($query)) {
@@ -1028,7 +1029,7 @@ class AmavisNewSQL {
 
          $res = $this->db->query($query);
          if(DB::isError($res)) {
-            $this->error = "DB Error = '".$this->dbErrorMessage($res)."' called from $calledfrom on line $line";
+            $this->error = "DB Error in ".__FUNCTION__." Message = '".$this->dbErrorMessage($res)."' called from $calledfrom on line $line";
             return FALSE;
          }
 
@@ -1039,11 +1040,11 @@ class AmavisNewSQL {
       * Connect to the database
       * @returns bool True on success or False on failure
       */
-      function connect($calledfrom=NULL, $line=NULL) {
+      function connect() {
          $this->error = null;
          $this->db = DB::connect($this->dsn, true);
          if (DB::isError($this->db) ) {
-            $this->error = $this->db->getMessage()." Called from $calledfrom on line $line";
+            $this->error = $this->db->getMessage();
             return FALSE;
          }
          return TRUE;
@@ -1054,11 +1055,10 @@ class AmavisNewSQL {
       * Disconnect from the database
       * @returns bool True on success False on failure
       */
-      function disconnect($calledfrom=NULL, $line=NULL) {
-         $this->error = null;
+      function disconnect() {
          $this->db->disconnect();
          if (DB::isError($this->db) ) {
-            $this->error = $this->db->getMessage()." Called from $calledfrom on line $line";
+            $this->error = $this->db->getMessage();
             return FALSE;
          }
          return TRUE;
