@@ -407,7 +407,7 @@ if(count($policyList) == 0) {
                         _("The tag level is the numerical score required to identify a message as being spam.  This will cause *SPAM* to be added to the subject line and the X-Spam-Flag header to be set to YES.") . "
                      </td>
                      <td colspan=2 valign=\"top\" bgcolor=\"$color[4]\"><center><b>$tag2_label</b></center><br>" .
-                        _("The $tag2_label is the numerical score required to prevent delivery of a message at the server.  This level should be higher or equal to Tag Level and high enough to avoid catching legitimate email. As your custom whitelist grows you should adjust these two levels to tag and block more spam.") . "
+                        _("The ") . _("$tag2_label") . _(" is the numerical score required to prevent delivery of a message at the server.  This level should be higher or equal to Tag Level and high enough to avoid catching legitimate email. As your custom whitelist grows you should adjust these two levels to tag and block more spam.") . "
                      </td>
                  </tr>
           </table>
